pub struct BlockHeaderPrintable {
Show 16 fields pub hash: String, pub version: u16, pub height: u64, pub previous: String, pub prev_root: String, pub timestamp: String, pub output_root: String, pub range_proof_root: String, pub kernel_root: String, pub nonce: u64, pub edge_bits: u8, pub proof: String, pub solution: Solution, pub total_difficulty: HashMap<PoWType, u64>, pub secondary_scaling: u32, pub total_kernel_offset: String,
}

Fields

hash: Stringversion: u16

Version of the block

height: u64

Height of this block since the genesis block (height 0)

previous: String

Hash of the block previous to this in the chain.

prev_root: String

Root hash of the header MMR at the previous header.

timestamp: String

rfc3339 timestamp at which the block was built.

output_root: String

Merklish root of all the commitments in the TxHashSet

range_proof_root: String

Merklish root of all range proofs in the TxHashSet

kernel_root: String

Merklish root of all transaction kernels in the TxHashSet

nonce: u64

Nonce increment used to mine this block.

edge_bits: u8

Size of the cuckoo graph

proof: String

Proof choosed

solution: Solution

Nonces of the cuckoo solution

total_difficulty: HashMap<PoWType, u64>

Total accumulated difficulty since genesis block

secondary_scaling: u32

Variable difficulty scaling factor for secondary proof of work

total_kernel_offset: String

Total kernel offset since genesis block

Implementations