pub struct TxHashSet {
    pub output_root_hash: String,
    pub range_proof_root_hash: String,
    pub kernel_root_hash: String,
}
TxHashSet

Fields

output_root_hash: String

Output Root Hash

range_proof_root_hash: Stringkernel_root_hash: String

Implementations

source

impl TxHashSet

source

pub fn from_head(chain: Arc<Chain>) -> Result<TxHashSet, Error>

A TxHashSet in the context of the api is simply the collection of PMMR roots. We can obtain these in a lightweight way by reading them from the head of the chain. We will have validated the roots on this header against the roots of the txhashset.