Struct stack_epic_api::BlockHeaderPrintable
source · pub struct BlockHeaderPrintable {Show 16 fields
pub hash: String,
pub version: u16,
pub height: u64,
pub previous: String,
pub prev_root: String,
pub timestamp: String,
pub output_root: String,
pub range_proof_root: String,
pub kernel_root: String,
pub nonce: u64,
pub edge_bits: u8,
pub proof: String,
pub solution: Solution,
pub total_difficulty: HashMap<PoWType, u64>,
pub secondary_scaling: u32,
pub total_kernel_offset: String,
}Fields
hash: Stringversion: u16Version of the block
height: u64Height of this block since the genesis block (height 0)
previous: StringHash of the block previous to this in the chain.
prev_root: StringRoot hash of the header MMR at the previous header.
timestamp: Stringrfc3339 timestamp at which the block was built.
output_root: StringMerklish root of all the commitments in the TxHashSet
range_proof_root: StringMerklish root of all range proofs in the TxHashSet
kernel_root: StringMerklish root of all transaction kernels in the TxHashSet
nonce: u64Nonce increment used to mine this block.
edge_bits: u8Size of the cuckoo graph
proof: StringProof choosed
solution: SolutionNonces of the cuckoo solution
total_difficulty: HashMap<PoWType, u64>Total accumulated difficulty since genesis block
secondary_scaling: u32Variable difficulty scaling factor for secondary proof of work
total_kernel_offset: StringTotal kernel offset since genesis block
Implementations
sourceimpl BlockHeaderPrintable
impl BlockHeaderPrintable
pub fn from_header(header: &BlockHeader) -> BlockHeaderPrintable